@@ -36,6 +36,10 @@ class run_test implements pts_option_interface
 	{
 		return array('run');
 	}
+	public static function invalid_command($passed_args = null)
+	{
+		pts_tests::invalid_command_helper($passed_args);
+	}
 	public static function run($to_run)
 	{
 		pts_test_run_manager::standard_run($to_run);
