@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2011, Phoronix Media
-	Copyright (C) 2009 - 2011, Michael Larabel
+	Copyright (C) 2009 - 2013, Phoronix Media
+	Copyright (C) 2009 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 class phoromatic extends pts_module_interface
 {
 	const module_name = 'Phoromatic Client';
-	const module_version = '1.0.0';
+	const module_version = '2.0.0';
 	const module_description = 'The Phoromatic client is used for connecting to a Phoromatic server (Phoromatic.com or a locally run server) to facilitate the automatic running of tests, generally across multiple test nodes in a routine manner. For more details visit http://www.phoromatic.com/';
 	const module_author = 'Phoronix Media';
 
@@ -33,6 +33,7 @@ class phoromatic extends pts_module_interface
 	static $phoromatic_account = null;
 	static $phoromatic_verifier = null;
 	static $phoromatic_system = null;
+	static $openbenchmarking_upload_json = null;
 
 	public static function module_info()
 	{
@@ -41,7 +42,7 @@ class phoromatic extends pts_module_interface
 	public static function module_setup()
 	{
 		return array(
-		new pts_module_option('remote_host', 'Enter the URL to host', 'HTTP_URL', 'https://www.phoromatic.com/'),
+		new pts_module_option('remote_host', 'Enter the URL to host', 'HTTP_URL', 'http://www.phoromatic.com/'),
 		new pts_module_option('remote_account', 'Enter the account code', 'ALPHA_NUMERIC'),
 		new pts_module_option('remote_verifier', 'Enter the verification code', 'ALPHA_NUMERIC'),
 		new pts_module_option('system_description', 'Enter a short (optional) description for this system', null, null, null, false)
@@ -99,11 +100,6 @@ class phoromatic extends pts_module_interface
 
 	public static function user_start()
 	{
-		if(PTS_IS_CLIENT)
-		{
-			echo PHP_EOL . PHP_EOL . 'NOTICE: A new version of Phoromatic is currently under development that is powered on top of the OpenBenchmarking.org infrastructure. Please contact Phoronix-Test-Suite.com if you are interested in testing out this brand new version with several new features.' . PHP_EOL . PHP_EOL;
-		}
-
 		if(pts_client::create_lock(PTS_USER_PATH . 'phoromatic_lock') == false)
 		{
 			pts_client::$display->generic_error('Phoromatic is already running.');
@@ -262,6 +258,7 @@ class phoromatic extends pts_module_interface
 
 	public static function user_system_process()
 	{
+		define('PHOROMATIC_PROCESS', true);
 		$last_communication_minute = date('i');
 		$communication_attempts = 0;
 		static $current_hw = null;
@@ -311,7 +308,6 @@ class phoromatic extends pts_module_interface
 			else
 			{
 				$server_response = phoromatic::upload_to_remote_server(array('r' => 'status_check'));
-
 				$xml_parser = new nye_XmlReader($server_response);
 				$response = $xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/Response');
 
@@ -324,7 +320,10 @@ class phoromatic extends pts_module_interface
 				$communication_attempts++;
 			}
 
-			echo ' [' . $response . ']' . PHP_EOL;
+			if($response != null)
+			{
+				echo ' [' . $response . ']' . PHP_EOL;
+			}
 
 			switch($response)
 			{
@@ -343,11 +342,18 @@ class phoromatic extends pts_module_interface
 					$phoromatic_schedule_id = $xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/ID');
 					$phoromatic_results_identifier = $xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/SystemName');
 					$phoromatic_trigger = $xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/Trigger');
+					self::$openbenchmarking_upload_json = null;
 
 					$suite_identifier = 'local/' . $suite_identifier;
 					if(pts_strings::string_bool($xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/RunInstallCommand', 'TRUE')))
 					{
 						phoromatic::set_user_context($xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/SetContextPreInstall'), $phoromatic_trigger, $phoromatic_schedule_id, 'INSTALL');
+
+						if(pts_strings::string_bool($xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/ForceInstallTests', 'TRUE')))
+						{
+							$test_flags |= pts_c::force_install;
+						}
+
 						pts_client::set_test_flags($test_flags);
 						pts_test_installer::standard_install($suite_identifier);
 					}
@@ -367,10 +373,12 @@ class phoromatic extends pts_module_interface
 							if(pts_strings::string_bool($xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/UploadToGlobal', 'FALSE')))
 							{
 								$test_run_manager->auto_upload_to_openbenchmarking();
+								pts_openbenchmarking_client::override_client_setting('UploadSystemLogsByDefault', pts_strings::string_bool($xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/UploadSystemLogs', 'TRUE')));
 							}
 
 							// Save results?
-							$test_run_manager->auto_save_results(date('Y-m-d H:i:s'), $phoromatic_results_identifier, 'A Phoromatic run.');
+							$save_identifier = date('Y-m-d H:i:s');
+							$test_run_manager->auto_save_results($save_identifier, $phoromatic_results_identifier, 'A Phoromatic run.');
 
 							// Run the actual tests
 							$test_run_manager->pre_execution_process();
@@ -382,7 +390,7 @@ class phoromatic extends pts_module_interface
 
 							// Upload test results
 
-							if(is_file(PTS_SAVE_RESULTS_PATH . $save_identifier . '/composite.xml'))
+							if(is_file(PTS_SAVE_RESULTS_PATH . $test_run_manager->get_file_name() . '/composite.xml'))
 							{
 								phoromatic::update_system_status('Uploading Test Results');
 
@@ -395,7 +403,7 @@ class phoromatic extends pts_module_interface
 										sleep(60);
 									}
 
-									$uploaded_test_results = phoromatic::upload_test_results($save_identifier, $phoromatic_schedule_id, $phoromatic_results_identifier, $phoromatic_trigger);
+									$uploaded_test_results = phoromatic::upload_test_results($test_run_manager->get_file_name(), $phoromatic_schedule_id, $phoromatic_results_identifier, $phoromatic_trigger, $xml_parser);
 									$times_tried++;
 								}
 								while($uploaded_test_results == false && $times_tried < 5);
@@ -408,7 +416,7 @@ class phoromatic extends pts_module_interface
 
 								if(pts_strings::string_bool($xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/ArchiveResultsLocally', 'TRUE')) == false)
 								{
-									pts_client::remove_saved_result_file($save_identifier);
+									pts_client::remove_saved_result_file($test_run_manager->get_file_name());
 								}
 							}
 						}
@@ -489,6 +497,10 @@ class phoromatic extends pts_module_interface
 			phoromatic::upload_unscheduled_test_results($test_run_manager->get_file_name());
 		}
 	}
+	public static function __event_openbenchmarking_upload($json)
+	{
+		self::$openbenchmarking_upload_json = $json;
+	}
 
 	//
 	// Other Functions
@@ -558,11 +570,11 @@ class phoromatic extends pts_module_interface
 
 		return self::read_xml_value($server_response, 'PhoronixTestSuite/Phoromatic/General/Response') == 'TRUE';
 	}
-	private static function capture_test_logs($save_identifier)
+	private static function capture_test_logs($save_identifier, &$xml_parser = null)
 	{
 		$data = array('system-logs' => null, 'test-logs' => null);
 
-		if(is_dir(PTS_SAVE_RESULTS_PATH . $save_identifier . '/system-logs/'))
+		if(is_dir(PTS_SAVE_RESULTS_PATH . $save_identifier . '/system-logs/') && ($xml_parser == null || $xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/UploadSystemLogs', 'FALSE')))
 		{
 			$system_logs_zip = pts_client::create_temporary_file();
 			pts_compression::zip_archive_create($system_logs_zip, PTS_SAVE_RESULTS_PATH . $save_identifier . '/system-logs/');
@@ -570,7 +582,7 @@ class phoromatic extends pts_module_interface
 			unlink($system_logs_zip);
 		}
 
-		if(is_dir(PTS_SAVE_RESULTS_PATH . $save_identifier . '/test-logs/'))
+		if(is_dir(PTS_SAVE_RESULTS_PATH . $save_identifier . '/test-logs/') && ($xml_parser == null || $xml_parser->getXMLValue('PhoronixTestSuite/Phoromatic/General/UploadTestLogs', 'FALSE')))
 		{
 			$test_logs_zip = pts_client::create_temporary_file();
 			pts_compression::zip_archive_create($test_logs_zip, PTS_SAVE_RESULTS_PATH . $save_identifier . '/test-logs/');
@@ -580,11 +592,20 @@ class phoromatic extends pts_module_interface
 
 		return $data;
 	}
-	protected static function upload_test_results($save_identifier, $phoromatic_schedule_id, $results_identifier, $phoromatic_trigger)
+	protected static function upload_test_results($save_identifier, $phoromatic_schedule_id, $results_identifier, $phoromatic_trigger, &$xml_parser = null)
 	{
 		$composite_xml = file_get_contents(PTS_SAVE_RESULTS_PATH . $save_identifier . '/composite.xml');
 
-		$logs = self::capture_test_logs($save_identifier);
+		if(self::$openbenchmarking_upload_json != null && isset(self::$openbenchmarking_upload_json['openbenchmarking']['upload']['id']))
+		{
+			$openbenchmarking_id = self::$openbenchmarking_upload_json['openbenchmarking']['upload']['id'];
+		}
+		else
+		{
+			$openbenchmarking_id = null;
+		}
+
+		$logs = self::capture_test_logs($save_identifier, $xml_parser);
 		$server_response = phoromatic::upload_to_remote_server(array(
 			'r' => 'upload_test_results',
 			'c' => $composite_xml,
@@ -592,7 +613,8 @@ class phoromatic extends pts_module_interface
 			'ti' => $results_identifier,
 			'ts' => $phoromatic_trigger,
 			'sl' => $logs['system-logs'],
-			'tl' => $logs['test-logs']
+			'tl' => $logs['test-logs'],
+			'ob' => $openbenchmarking_id,
 			));
 
 		return self::read_xml_value($server_response, 'PhoronixTestSuite/Phoromatic/General/Response') == 'TRUE';
