@@ -23,6 +23,7 @@
 class pts_client
 {
 	public static $display;
+	private static $current_command = null;
 	protected static $lock_pointers = null;
 
 	public static function create_lock($lock_file)
@@ -1248,6 +1249,8 @@ class pts_client
 
 		if(is_file(PTS_COMMAND_PATH . $command . '.php'))
 		{
+			self::$current_command = $command;
+
 			if(method_exists($command, 'run'))
 			{
 				call_user_func(array($command, 'run'), $pass_args);
@@ -1268,6 +1271,10 @@ class pts_client
 
 		pts_module_manager::module_process('__post_option_process', $command);
 	}
+	public static function current_command()
+	{
+		return self::$current_command;
+	}
 	public static function terminal_width()
 	{
 		static $terminal_width = null;
@@ -1511,24 +1518,14 @@ class pts_client
 	}
 	public static function display_web_page($URL, $alt_text = null, $default_open = true, $auto_open = false)
 	{
-		if(((pts_c::$test_flags & pts_c::auto_mode) && $auto_open == false && $default_open == false) || (pts_client::read_env('DISPLAY') == false && phodevi::is_windows() == false && phodevi::is_macosx() == false))
+		if(((pts_c::$test_flags & pts_c::auto_mode) && $auto_open == false && $default_open == false) || (pts_client::read_env('DISPLAY') == false && phodevi::is_windows() == false && phodevi::is_macosx() == false) || defined('PHOROMATIC_PROCESS'))
 		{
 			return;
 		}
 
-		// Launch the web browser
-		$text = $alt_text == null ? 'Do you want to view the results in your web browser' : $alt_text;
-
 		if($auto_open == false)
 		{
-			if((pts_c::$test_flags & pts_c::batch_mode))
-			{
-				$view_results = pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/OpenBrowser', 'FALSE');
-			}
-			else
-			{
-				$view_results = pts_user_io::prompt_bool_input($text, $default_open);
-			}
+			$view_results = pts_user_io::prompt_bool_input(($alt_text == null ? 'Do you want to view the results in your web browser' : $alt_text), $default_open);
 		}
 		else
 		{
