@@ -608,16 +608,20 @@ class pts_test_run_manager
 
 				if(!empty($test_identifier))
 				{
-					// XXX : add to attributes JSON here
-					$json_report_attributes = null;
+					$this->result_file_writer->add_result_from_result_object_with_value_string($test_run_request, $test_run_request->get_result(), $test_run_request->test_result_buffer->get_values_as_string(), self::process_json_report_attributes($test_run_request));
 
-					if(($t = $test_run_request->test_profile->test_installation->get_compiler_data()))
+					if($test_run_request->secondary_linked_results != null && is_array($test_run_request->secondary_linked_results))
 					{
-						$json_report_attributes['compiler-options'] = $t;
+						foreach($test_run_request->secondary_linked_results as &$run_request_minor)
+						{
+							if(strpos($run_request_minor->get_arguments_description(), $test_run_request->get_arguments_description()) === false)
+							{
+								$run_request_minor->set_used_arguments_description($test_run_request->get_arguments_description() . ' - ' . $run_request_minor->get_arguments_description());
+							}
+							$this->result_file_writer->add_result_from_result_object_with_value_string($run_request_minor, $run_request_minor->get_result(), null, self::process_json_report_attributes($run_request_minor));
+						}
 					}
 
-					$this->result_file_writer->add_result_from_result_object_with_value_string($test_run_request, $test_run_request->get_result(), $test_run_request->test_result_buffer->get_values_as_string(), $json_report_attributes);
-
 					if($this->get_results_identifier() != null && $this->get_file_name() != null && pts_config::read_bool_config('PhoronixTestSuite/Options/Testing/SaveTestLogs', 'FALSE'))
 					{
 						static $xml_write_pos = 1;
@@ -654,6 +658,26 @@ class pts_test_run_manager
 
 		return true;
 	}
+	protected static function process_json_report_attributes(&$test_run_request)
+	{
+		// XXX : add to attributes JSON here
+		$json_report_attributes = null;
+
+		if(($t = $test_run_request->test_profile->test_installation->get_compiler_data()))
+		{
+			$json_report_attributes['compiler-options'] = $t;
+		}
+		if(($t = $test_run_request->get_min_result()) != 0)
+		{
+			$json_report_attributes['min-result'] = $t;
+		}
+		if(($t = $test_run_request->get_max_result()) != 0)
+		{
+			$json_report_attributes['max-result'] = $t;
+		}
+
+		return $json_report_attributes;
+	}
 	public static function clean_save_name($input, $is_new_save = true)
 	{
 		$input = pts_client::swap_variables($input, array('pts_client', 'user_run_save_variables'));
@@ -812,6 +836,16 @@ class pts_test_run_manager
 			}
 		}
 
+		if(phodevi::read_property('system', 'kernel-parameters'))
+		{
+			$notes['kernel-parameters'] = phodevi::read_property('system', 'kernel-parameters');
+		}
+
+		if(phodevi::read_property('system', 'environment-variables'))
+		{
+			$notes['environment-variables'] = phodevi::read_property('system', 'environment-variables');
+		}
+
 		return $notes;
 	}
 	public function post_execution_process()
@@ -836,7 +870,8 @@ class pts_test_run_manager
 			pts_client::save_result_file($this->result_file_writer, $this->get_file_name());
 			pts_module_manager::module_process('__event_results_saved', $this);
 			//echo PHP_EOL . 'Results Saved To: ; . PTS_SAVE_RESULTS_PATH . $this->get_file_name() . ;/composite.xml' . PHP_EOL;
-			pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/index.html');
+			$auto_open = (pts_c::$test_flags & pts_c::batch_mode) ? self::$batch_mode_options['OpenBrowser'] : false;
+			pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/index.html', null, true, $auto_open);
 
 			if($this->allow_sharing_of_results && pts_network::network_support_available())
 			{
@@ -886,6 +921,7 @@ class pts_test_run_manager
 			'PromptSaveName' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptSaveName', 'FALSE'),
 			'PromptForTestIdentifier' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptForTestIdentifier', 'TRUE'),
 			'Configured' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/Configured', 'FALSE'),
+			'OpenBrowser' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/OpenBrowser', 'FALSE'),
 			);
 
 		if($custom_preset && is_array($custom_preset))
@@ -1017,7 +1053,7 @@ class pts_test_run_manager
 				echo $message;
 			}
 
-			if((pts_c::$test_flags & pts_c::auto_mode) == false && (pts_c::$test_flags & pts_c::batch_mode) == false && pts_flags::is_live_cd() == false)
+			if((pts_c::$test_flags & pts_c::auto_mode) == false && (pts_c::$test_flags & pts_c::batch_mode) == false && pts_flags::is_live_cd() == false && pts_client::current_command() != 'benchmark')
 			{
 				$stop_and_install = pts_user_io::prompt_bool_input('Would you like to stop and install these tests now', true);
 
@@ -1467,6 +1503,7 @@ class pts_test_run_manager
 		$valid_test_profile = true;
 		$test_type = $test_profile->get_test_hardware_type();
 		$skip_tests = pts_client::read_env('SKIP_TESTS') ? pts_strings::comma_explode(pts_client::read_env('SKIP_TESTS')) : false;
+		$only_test_types = ($e = pts_client::read_env('ONLY_TEST_TYPES')) ? pts_strings::comma_explode($e) : false;
 		$display_driver = phodevi::read_property('system', 'display-driver');
 		$gpu = phodevi::read_name('gpu');
 
@@ -1495,6 +1532,11 @@ class pts_test_run_manager
 			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environmental variable, skipping ' . $test_profile);
 			$valid_test_profile = false;
 		}
+		else if($only_test_types && !in_array($test_profile->get_test_hardware_type(), $only_test_types))
+		{
+			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environmental variable, skipping ' . $test_profile);
+			$valid_test_profile = false;
+		}
 		else if($test_profile->is_root_required() && (pts_c::$test_flags & pts_c::batch_mode) && phodevi::is_root() == false)
 		{
 			$report_errors && pts_client::$display->test_run_error('Cannot run ' . $test_profile . ' in batch mode as root access is required.');
@@ -1503,8 +1545,8 @@ class pts_test_run_manager
 
 		if($valid_test_profile == false && pts_client::read_env('SKIP_ALL_TEST_SUPPORT_CHECKS'))
 		{
-			$valid_test_profile = true;
 			$report_errors && pts_client::$display->test_run_error('SKIP_ALL_TEST_SUPPORT_CHECKS is set for ' . $test_profile . '.');
+			$valid_test_profile = true;
 		}
 
 		return $valid_test_profile;
