@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2011, Phoronix Media
-	Copyright (C) 2010 - 2011, Michael Larabel
+	Copyright (C) 2010 - 2012, Phoronix Media
+	Copyright (C) 2010 - 2012, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ class pts_suite_nye_XmlReader extends nye_XmlReader
 {
 	public function __construct($read_xml)
 	{
-		if(!isset($xml_file[512]) && is_file(PTS_TEST_SUITE_PATH . $read_xml . '/suite-definition.xml'))
+		if(!isset($xml_file[512]) && defined('PTS_TEST_SUITE_PATH') && is_file(PTS_TEST_SUITE_PATH . $read_xml . '/suite-definition.xml'))
 		{
 			$read_xml = PTS_TEST_SUITE_PATH . $read_xml . '/suite-definition.xml';
 		}
