@@ -44,7 +44,15 @@ class phodevi_audio extends phodevi_device_interface
 		}
 		else if(phodevi::is_bsd())
 		{
-			// TODO: implement
+			foreach(array('dev.hdac.0.%desc') as $dev)
+			{
+				$dev = phodevi_bsd_parser::read_sysctl($dev);
+
+				if(!empty($dev))
+				{
+					$audio = $dev;
+				}
+			}
 		}
 		else if(phodevi::is_windows())
 		{
@@ -52,7 +60,7 @@ class phodevi_audio extends phodevi_device_interface
 		}
 		else if(phodevi::is_linux())
 		{
-			foreach(pts_file_io::glob('/sys/class/sound/card*/hwC0D0/vendor_name') as $vendor_name)
+			foreach(pts_file_io::glob('/sys/class/sound/card*/hwC0D*/vendor_name') as $vendor_name)
 			{
 				$card_dir = dirname($vendor_name) . '/';
 
@@ -70,9 +78,20 @@ class phodevi_audio extends phodevi_device_interface
 				if(strpos($chip_name, 'HDMI') === false)
 				{
 					// If HDMI is in the audio string, likely the GPU-provided audio, so try to find the mainboard otherwise
+					$chip = null;
 					break;
 				}
 			}
+
+			if($audio == null)
+			{
+				$audio = phodevi_linux_parser::read_pci('Multimedia audio controller');
+			}
+
+			if($audio == null)
+			{
+				$audio = phodevi_linux_parser::read_pci('Audio device');
+			}
 		}
 
 		return $audio;
