@@ -238,6 +238,14 @@ class phodevi_gpu extends phodevi_device_interface
 				$aa_level = $gallium_msaa . 'x MSAA';
 			}
 		}
+		else if(getenv('__GL_FSAA_MODE'))
+		{
+			$gl_msaa = getenv('__GL_FSAA_MODE');
+			if(is_numeric($gl_msaa) && $gl_msaa > 0)
+			{
+				$aa_level = '__GL_FSAA_MODE=' . $gallium_msaa;
+			}
+		}
 
 		return $aa_level;
 	}
@@ -289,6 +297,30 @@ class phodevi_gpu extends phodevi_device_interface
 				}
 			}
 		}
+		else if(getenv('__GL_LOG_MAX_ANISO'))
+		{
+			$max_aniso = getenv('__GL_LOG_MAX_ANISO');
+			if(is_numeric($max_aniso) && $max_aniso > 0)
+			{
+				switch($max_aniso)
+				{
+					case 1:
+						$max_aniso = '2x';
+						break;
+					case 2:
+						$max_aniso = '4x';
+						break;
+					case 3:
+						$max_aniso = '8x';
+						break;
+					case 4:
+						$max_aniso = '16x';
+						break;
+				}
+
+				$af_level = $max_aniso;
+			}
+		}
 
 		return $af_level;
 	}
@@ -316,13 +348,17 @@ class phodevi_gpu extends phodevi_device_interface
 			if(strpos($info, '*') !== false)
 			{
 				$res = pts_strings::trim_explode('x', $info);
-				$res[0] = substr($res[0], strrpos($res[0], ' '));
-				$res[1] = substr($res[1], 0, strpos($res[1], ' '));
-				$res = array_map('trim', $res);
 
-				if(is_numeric($res[0]) && is_numeric($res[1]))
+				if(isset($res[1]))
 				{
-					$resolution = array($res[0], $res[1]);
+					$res[0] = substr($res[0], strrpos($res[0], ' '));
+					$res[1] = substr($res[1], 0, strpos($res[1], ' '));
+					$res = array_map('trim', $res);
+
+					if(is_numeric($res[0]) && is_numeric($res[1]))
+					{
+						$resolution = array($res[0], $res[1]);
+					}
 				}
 			}
 		}
@@ -496,11 +532,18 @@ class phodevi_gpu extends phodevi_device_interface
 		{
 			// Fallback to providing stock modes
 			$stock_modes = array(
-				array(800, 600), array(1024, 768),
-				array(1280, 1024), array(1400, 900),
-				array(1400, 1050), array(1600, 900),
-				array(1680, 1050), array(1600, 1200),
-				array(1920, 1080), array(2560, 1600));
+				array(800, 600),
+				array(1024, 768),
+				array(1280, 800),
+				array(1280, 1024),
+				array(1400, 900),
+				array(1400, 1050),
+				array(1600, 900),
+				array(1680, 1050),
+				array(1600, 1200),
+				array(1920, 1080),
+				array(1920, 1200),
+				array(2560, 1600));
 			$available_modes = array();
 
 			for($i = 0; $i < count($stock_modes); $i++)
@@ -794,32 +837,69 @@ class phodevi_gpu extends phodevi_device_interface
 				case 'radeon':
 					if(isset(phodevi::$vfs->radeon_pm_info))
 					{
-						// radeon_pm_info should be present with Linux 2.6.34+
-						foreach(pts_strings::trim_explode("\n", phodevi::$vfs->radeon_pm_info) as $pm_line)
+						// radeon_pm_info should be present with Linux 2.6.34+ but was changed with Linux 3.11 Radeon DPM
+						if(stripos(phodevi::$vfs->radeon_pm_info, 'default'))
 						{
-							if($pm_line == null)
+							foreach(pts_strings::trim_explode("\n", phodevi::$vfs->radeon_pm_info) as $pm_line)
 							{
-								continue;
-							}
+								if($pm_line == null)
+								{
+									continue;
+								}
 
-							list($descriptor, $value) = pts_strings::colon_explode($pm_line);
+								list($descriptor, $value) = pts_strings::colon_explode($pm_line);
 
-							switch($descriptor)
-							{
-								case 'default engine clock':
-									$core_freq = pts_arrays::first_element(explode(' ', $value)) / 1000;
-									break;
-								case 'default memory clock':
-									$mem_freq = pts_arrays::first_element(explode(' ', $value)) / 1000;
-									break;
+								switch($descriptor)
+								{
+									case 'default engine clock':
+										$core_freq = pts_arrays::first_element(explode(' ', $value)) / 1000;
+										break;
+									case 'default memory clock':
+										$mem_freq = pts_arrays::first_element(explode(' ', $value)) / 1000;
+										break;
+								}
 							}
 						}
 					}
-					else
+
+					if($core_freq == null)
+					{
+						// Attempt to read the LAST power level reported to dmesg, this is the current way for Radeon DPM on Linux 3.11+
+						$dmesg_parse = isset(phodevi::$vfs->dmesg) ? phodevi::$vfs->dmesg : null;
+						if(($x = strrpos($dmesg_parse, ' sclk:')))
+						{
+							$dmesg_parse = substr($dmesg_parse, $x);
+							$dmesg_parse = explode(' ', substr($dmesg_parse, 0, strpos($dmesg_parse, PHP_EOL)));
+
+							$sclk = array_search('sclk:', $dmesg_parse);
+							if($sclk !== false && isset($dmesg_parse[($sclk + 1)]) && is_numeric($dmesg_parse[($sclk + 1)]))
+							{
+								$sclk = $dmesg_parse[($sclk + 1)];
+								if($sclk > 10000)
+								{
+									$sclk = $sclk / 100;
+								}
+
+								$core_freq = $sclk;
+							}
+							$mclk = array_search('mclk:', $dmesg_parse);
+							if($mclk !== false && isset($dmesg_parse[($mclk + 1)]) && is_numeric($dmesg_parse[($mclk + 1)]))
+							{
+								$mclk = $dmesg_parse[($mclk + 1)];
+								if($mclk > 10000)
+								{
+									$mclk = $mclk / 100;
+								}
+
+								$mem_freq = $mclk;
+							}
+						}
+					}
+
+					if($core_freq == null)
 					{
 						// Old ugly way of handling the clock information
 						$log_parse = isset(phodevi::$vfs->xorg_log) ? phodevi::$vfs->xorg_log : null;
-
 						if(($engine_clock = strpos($log_parse, 'Default Engine Clock: ')))
 						{
 							$core_freq = substr($log_parse, $engine_clock + 22);
@@ -837,11 +917,22 @@ class phodevi_gpu extends phodevi_device_interface
 								$core_freq = 0;
 							}
 						}
-					}				
+					}
 					break;
 				case 'intel':
 					// try to read the maximum dynamic frequency
-					if(is_file('/sys/kernel/debug/dri/0/i915_max_freq'))
+					if(is_file('/sys/class/drm/card0/gt_max_freq_mhz'))
+					{
+						$gt_max_freq_mhz = pts_file_io::file_get_contents('/sys/class/drm/card0/gt_max_freq_mhz');
+
+						if(is_numeric($gt_max_freq_mhz) && $gt_max_freq_mhz > 100)
+						{
+							// Tested on Linux 3.11. Assume the max frequency on any competent GPU is beyond 100MHz
+							$core_freq = $gt_max_freq_mhz;
+						}
+					}
+
+					if($core_freq == 0 && is_file('/sys/kernel/debug/dri/0/i915_max_freq'))
 					{
 						$i915_max_freq = pts_file_io::file_get_contents('/sys/kernel/debug/dri/0/i915_max_freq');
 						$freq_mhz = substr($i915_max_freq, strpos($i915_max_freq, ': ') + 2);
@@ -1076,7 +1167,24 @@ class phodevi_gpu extends phodevi_device_interface
 							*/
 
 							$xorg_log = phodevi::$vfs->xorg_log;
-							if(($x = strpos($xorg_log, '(0): Chipset: ')) !== false)
+							if(($x = strpos($xorg_log, 'Integrated Graphics Chipset: ')) !== false)
+							{
+								$xorg_log = substr($xorg_log, ($x + 29));
+								$xorg_log = str_replace(array('(R)', '"'), null, substr($xorg_log, 0, strpos($xorg_log, PHP_EOL)));
+
+								if(stripos($xorg_log, 'Intel') === false)
+								{
+									$xorg_log = 'Intel ' . $xorg_log;
+								}
+
+								// if string is too long, likely not product
+								if(!isset($xorg_log[45]))
+								{
+									$info = $xorg_log;
+									$was_reset = true;
+								}
+							}
+							else if(($x = strpos($xorg_log, '(0): Chipset: ')) !== false)
 							{
 								$xorg_log = substr($xorg_log, ($x + 14));
 								$xorg_log = str_replace(array('(R)', '"'), null, substr($xorg_log, 0, strpos($xorg_log, PHP_EOL)));
@@ -1200,6 +1308,11 @@ class phodevi_gpu extends phodevi_device_interface
 			$info = 'AMD ' . $info;
 		}
 
+		if(phodevi::is_linux() && ($vendor = phodevi_linux_parser::read_pci_subsystem_value('VGA compatible controller')) != null && stripos($info, $vendor) === false && (stripos($info, 'AMD') !== false || stripos($info, 'NVIDIA') !== false))
+		{
+			$info = $vendor . ' ' . $info;
+		}
+
 		if($video_ram > 64 && strpos($info, $video_ram) == false) // assume more than 64MB of vRAM
 		{
 			$info .= ' ' . $video_ram . 'MB';
