@@ -87,12 +87,18 @@ class phodevi_system extends phodevi_device_interface
 			case 'kernel-string':
 				$property = new phodevi_device_property('sw_kernel_string', phodevi::smart_caching);
 				break;
+			case 'kernel-parameters':
+				$property = new phodevi_device_property('sw_kernel_parameters', phodevi::std_caching);
+				break;
 			case 'compiler':
 				$property = new phodevi_device_property('sw_compiler', phodevi::std_caching);
 				break;
 			case 'system-layer':
 				$property = new phodevi_device_property('sw_system_layer', phodevi::std_caching);
 				break;
+			case 'environment-variables':
+				$property = new phodevi_device_property('sw_environment_variables', phodevi::std_caching);
+				break;
 		}
 
 		return $property;
@@ -314,7 +320,8 @@ class phodevi_system extends phodevi_device_interface
 							'0x61756673' => 'AuFS',
 							'0xbd00bd0' => 'Lustre',
 							'0xaad7aaea' => 'PanFS', // Panasas FS
-							'0xf2f52010' => 'F2FS'
+							'0xf2f52010' => 'F2FS',
+							'0xc36400' => 'CephFS',
 							);
 
 						foreach($known_magic_blocks as $hex => $name)
@@ -467,8 +474,63 @@ class phodevi_system extends phodevi_device_interface
 			$virtualized = ucwords($type) . ' ' . implode('', $version) . ' Hypervisor';
 		}
 
+		if($systemd_virt = pts_client::executable_in_path('systemd-detect-virt'))
+		{
+			$systemd_virt = trim(shell_exec($systemd_virt . ' 2> /dev/null'));
+
+			if($systemd_virt != null && $systemd_virt != 'none')
+			{
+				switch($systemd_virt)
+				{
+					case 'kvm':
+						$systemd_virt = 'KVM';
+						break;
+					case 'oracle':
+						$systemd_virt = 'Oracle';
+						break;
+				}
+
+				if($virtualized != null && stripos($virtualized, $systemd_virt) === false && stripos($systemd_virt, $virtualized) === false)
+				{
+					$virtualized = $systemd_virt . ' ' . $virtualized;
+				}
+				else if($virtualized == null)
+				{
+					$virtualized = $systemd_virt;
+				}
+			}
+		}
+
 		return $virtualized;
 	}
+	public static function sw_environment_variables()
+	{
+		$check_variables = array('LIBGL', '__GL', 'DRI_');
+		$to_report = array();
+
+		if(stripos(phodevi::read_property('system', 'opengl-driver'), 'Mesa'))
+		{
+			array_push($check_variables, 'MESA', 'GALLIUM');
+		}
+
+		if(isset($_SERVER))
+		{
+			foreach($_SERVER as $name => &$value)
+			{
+				foreach($check_variables as $var)
+				{
+					if(stripos($name, $var) !== false)
+					{
+						array_push($to_report, $name . '=' . $value);
+						break;
+					}
+				}
+
+			}
+		}
+
+		return implode(' ', array_unique($to_report));
+	}
 	public static function sw_compiler()
 	{
 		// Returns version of the compiler (if present)
@@ -745,6 +807,48 @@ class phodevi_system extends phodevi_device_interface
 	{
 		return php_uname('r');
 	}
+	public static function sw_kernel_parameters()
+	{
+		$parameters = null;
+
+		if(is_file('/proc/cmdline') && is_file('/proc/modules'))
+		{
+			$modules = array();
+
+			foreach(explode(PHP_EOL, pts_file_io::file_get_contents('/proc/modules')) as $module_line)
+			{
+				$module_line = explode(' ', $module_line);
+
+				if(isset($module_line[0]) && !empty($module_line[0]))
+				{
+					array_push($modules, $module_line[0]);
+				}
+			}
+
+			if(!empty($modules))
+			{
+				$to_report = array();
+				$cmdline = explode(' ', pts_file_io::file_get_contents('/proc/cmdline'));
+				foreach($cmdline as $option)
+				{
+					if(($t = strpos($option, '.')) !== false)
+					{
+						if(in_array(substr($option, 0, $t), $modules))
+						{
+							array_push($to_report, $option);
+						}
+					}
+				}
+
+				if(!empty($to_report))
+				{
+					$parameters = implode(' ', $to_report);
+				}
+			}
+		}
+
+		return $parameters;
+	}
 	public static function sw_kernel_architecture()
 	{
 		// Find out the kernel archiecture
@@ -913,6 +1017,11 @@ class phodevi_system extends phodevi_device_interface
 			$os = phodevi_osx_parser::read_osx_system_profiler('SPSoftwareDataType', 'SystemVersion');
 		}
 
+		if(($break_point = strpos($os, '(')) > 0)
+		{
+			$os = substr($os, 0, $break_point);
+		}
+
 		$os = trim($os);
 
 		return $os;
@@ -1060,6 +1169,11 @@ class phodevi_system extends phodevi_device_interface
 			$desktop_environment = 'Razor-qt';
 			$desktop_version = null; // TODO: Figure out how to determine razor version
 		}
+		else if(pts_client::is_process_running('icewm'))
+		{
+			$desktop_environment = 'IceWM';
+			$desktop_version = null;
+		}
 
 		if(!empty($desktop_environment))
 		{
@@ -1113,6 +1227,17 @@ class phodevi_system extends phodevi_device_interface
 			{
 				$info = 'SurfaceFlinger';
 			}
+
+			if(pts_client::is_process_running('unity-system-compositor'))
+			{
+				$unity_system_comp = trim(str_replace('unity-system-compositor', null, shell_exec('unity-system-compositor --version 2>&1')));
+
+				if(pts_strings::is_version($unity_system_comp))
+				{
+					$info = 'Unity-System-Compositor ' . $unity_system_comp . ($info != null ? ' + ' . $info : null);
+				}
+
+			}
 		}
 
 		return $info;
@@ -1241,7 +1366,7 @@ class phodevi_system extends phodevi_device_interface
 				}
 			}
 
-			if(!empty($driver_version) && $with_version)
+			if(!empty($driver_version) && $with_version && $driver_version != '0.0.0')
 			{
 				$display_driver .= ' ' . $driver_version;
 
