@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2012, Phoronix Media
-	Copyright (C) 2008 - 2012, Michael Larabel
+	Copyright (C) 2008 - 2013, Phoronix Media
+	Copyright (C) 2008 - 2013, Michael Larabel
 	phodevi_linux_parser.php: General parsing functions specific to Linux
 
 	This program is free software; you can redistribute it and/or modify
@@ -576,6 +576,11 @@ class phodevi_linux_parser
 				$info = substr($output, $pos + strlen($desc) + 1);
 				$info = trim(substr($info, 0, strpos($info, "\n")));
 			}
+
+			if(strtolower($info) == 'n/a')
+			{
+				$info = false;
+			}
 		}
 
 		return $info;
@@ -614,6 +619,47 @@ class phodevi_linux_parser
 
 		return $value;
 	}
+	public static function read_pci_subsystem_value($desc)
+	{
+		$lspci = shell_exec('lspci -v 2> /dev/null');
+		$subsystem = null;
+
+		foreach(pts_arrays::to_array($desc) as $check)
+		{
+			if(($hit = strpos($lspci, $check)) !== false)
+			{
+				$lspci = substr($lspci, $hit);
+
+				if(($hit = strpos($lspci, 'Subsystem: ')) !== false)
+				{
+					$lspci = substr($lspci, ($hit + strlen('Subsystem: ')));
+					$lspci = substr($lspci, 0, strpos($lspci, PHP_EOL));
+
+					$vendors = array(
+						'Sapphire Technology' => 'Sapphire',
+						'PC Partner' => 'Sapphire',
+						'Micro-Star International' => 'MSI',
+						'XFX' => 'XFX',
+						'ASUS' => 'ASUS',
+						'Gigabyte' => 'Gigabyte',
+						'Elitegroup' => 'ECS',
+						'eVga' => 'eVGA',
+						);
+
+					foreach($vendors as $vendor => $clean_vendor)
+					{
+						if(stripos($lspci, $vendor) !== false)
+						{
+							$subsystem = $clean_vendor;
+							break;
+						}
+					}
+				}
+			}
+		}
+
+		return $subsystem;
+	}
 	public static function read_pci($desc, $clean_string = true)
 	{
 		// Read PCI bus information
@@ -648,7 +694,7 @@ class phodevi_linux_parser
 
 			if(($pos = strpos($pci_info, $desc[$i])) !== false)
 			{
-				$sub_pci_info = str_replace(array('[AMD]'), null, substr($pci_info, $pos + strlen($desc[$i])));
+				$sub_pci_info = str_replace(array('[AMD]', '[AMD/ATI]'), null, substr($pci_info, $pos + strlen($desc[$i])));
 				$EOL = strpos($sub_pci_info, "\n");
 
 				if($clean_string)
@@ -674,7 +720,7 @@ class phodevi_linux_parser
 
 				$sub_pci_info = trim(substr($sub_pci_info, 0, $EOL));
 
-				if(($strlen = strlen($sub_pci_info)) >= 6 && $strlen < 96)
+				if(($strlen = strlen($sub_pci_info)) >= 6 && $strlen < 128)
 				{
 					$info = pts_strings::strip_string($sub_pci_info);
 				}
