@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009, Phoronix Media
-	Copyright (C) 2009, Michael Larabel
+	Copyright (C) 2009 - 2010, Phoronix Media
+	Copyright (C) 2009 - 2010, Michael Larabel
 	phodevi_osx_parser.php: General parsing functions specific to Mac OS X
 
 	This program is free software; you can redistribute it and/or modify
@@ -27,22 +27,28 @@ class phodevi_osx_parser
 	{
 		$value = ($multiple_objects ? array() : false);
 
-		if(pts_client::executable_in_path("system_profiler"))
+		if(pts_client::executable_in_path('system_profiler'))
 		{
-			$info = trim(shell_exec("system_profiler " . $data_type . " 2>&1"));
+			$info = trim(shell_exec('system_profiler ' . $data_type . ' 2>&1'));
 			$lines = explode("\n", $info);
 
 			for($i = 0; $i < count($lines) && ($value == false || $multiple_objects); $i++)
 			{
 				$line = pts_strings::colon_explode($lines[$i]);
-				$line_object = str_replace(" ", "", $line[0]);
+
+				if(isset($line[0]) == false)
+				{
+					continue;
+				}
+
+				$line_object = str_replace(' ', null, $line[0]);
 		
-				if(($cut_point = strpos($line_object, "(")) > 0)
+				if(($cut_point = strpos($line_object, '(')) > 0)
 				{
 					$line_object = substr($line_object, 0, $cut_point);
 				}
 		
-				if($line_object == $object && isset($line[1]))
+				if(strtolower($line_object) == strtolower($object) && isset($line[1]))
 				{
 					$this_value = trim($line[1]);
 			
