@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2012, Phoronix Media
-	Copyright (C) 2009 - 2012, Michael Larabel
+	Copyright (C) 2009 - 2013, Phoronix Media
+	Copyright (C) 2009 - 2013, Michael Larabel
 	phodevi.php: The object for interacting with the PTS device framework
 
 	This program is free software; you can redistribute it and/or modify
@@ -231,21 +231,6 @@ class phodevi extends phodevi_base
 
 		return is_array($notes_r) ? $notes_r : array();
 	}
-	public static function read_special_settings_string($device)
-	{
-		$devices = phodevi::available_hardware_devices();
-
-		if(isset($devices[$device]))
-		{
-			$settings_special = call_user_func(array('phodevi_' . $devices[$device], 'special_settings_string'));
-		}
-		else
-		{
-			$settings_special = null;
-		}
-
-		return $settings_special;
-	}
 	public static function read_property($device, $read_property)
 	{
 		$value = false;
@@ -283,6 +268,10 @@ class phodevi extends phodevi_base
 					if(!is_array($value) && $value != null)
 					{
 						$value = pts_strings::strip_string($value);
+						if(function_exists('preg_replace'))
+						{
+							$value = preg_replace('/[^(\x20-\x7F)]*/','', $value);
+						}
 					}
 
 					if($cache_code != phodevi::no_caching)
@@ -377,6 +366,11 @@ class phodevi extends phodevi_base
 			self::$device_cache = array_merge(self::$device_cache, $cache_array);
 		}
 	}
+	public static function clear_cache()
+	{
+		self::$smart_cache = array();
+		self::$device_cache = array();
+	}
 	public static function get_phodevi_cache_object($store_dir, $client_version = 0)
 	{
 		return new phodevi_cache(self::$smart_cache, $store_dir, $client_version);
