@@ -92,6 +92,45 @@ class gpu_freq implements phodevi_sensor
 							break;
 					}
 				}
+
+				if($core_freq == null && ($x = strpos(phodevi::$vfs->radeon_pm_info, 'sclk: ')))
+				{
+					$x = substr(phodevi::$vfs->radeon_pm_info, ($x + strlen('sclk: ')));
+					$x = substr($x, 0, strpos($x, ' '));
+
+					if(is_numeric($x))
+					{
+						if($x > 1000)
+						{
+							$x = $x / 100;
+						}
+
+						$core_freq = $x;
+					}
+				}
+				if($mem_freq == null && ($x = strpos(phodevi::$vfs->radeon_pm_info, 'mclk: ')))
+				{
+					$x = substr(phodevi::$vfs->radeon_pm_info, ($x + strlen('mclk: ')));
+					$x = substr($x, 0, strpos($x, ' '));
+
+					if(is_numeric($x))
+					{
+						if($x > 1000)
+						{
+							$x = $x / 100;
+						}
+
+						$mem_freq = $x;
+					}
+				}
+			}
+			else if(is_file('/sys/class/drm/card0/gt_cur_freq_mhz'))
+			{
+				$gt_cur_freq_mhz = pts_file_io::file_get_contents('/sys/class/drm/card0/gt_cur_freq_mhz');
+				if($gt_cur_freq_mhz > 2)
+				{
+					$core_freq = $gt_cur_freq_mhz;
+				}
 			}
 			else if(is_file('/sys/class/drm/card0/device/performance_level'))
 			{
