@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2012, Phoronix Media
+	Copyright (C) 2008 - 2012, Michael Larabel
 	pts_PassFailGraph.php: An abstract graph object extending pts_Graph for showing results in a pass/fail scenario.
 
 	This program is free software; you can redistribute it and/or modify
@@ -26,9 +26,9 @@ class pts_PassFailGraph extends pts_Graph
 	public function __construct(&$result_object, &$result_file = null)
 	{
 		parent::__construct($result_object, $result_file);
-		$this->graph_value_type = "ABSTRACT";
-		$this->graph_hide_identifiers = true;
-		$this->graph_data_title = array("PASSED", "FAILED");
+		$this->i['graph_value_type'] = 'ABSTRACT';
+		$this->i['hide_graph_identifiers'] = true;
+		$this->graph_data_title = array('PASSED', 'FAILED');
 	}
 	protected function render_graph_passfail()
 	{
@@ -37,9 +37,9 @@ class pts_PassFailGraph extends pts_Graph
 		$horizontal_border = 10;
 		$spacing = 8;
 		$columns = 1;
-		$graph_width = $this->graph_left_end - $this->graph_left_start - ($horizontal_border * 2);
-		$graph_height = $this->graph_top_end - $this->graph_top_start - ($vertical_border * 1.5);
-		$font_size = $this->graph_font_size_bars * 1.5;
+		$graph_width = $this->i['graph_left_end'] - $this->i['left_start'] - ($horizontal_border * 2);
+		$graph_height = $this->i['graph_top_end'] - $this->i['top_start'] - ($vertical_border * 1.5);
+		$font_size = self::$c['size']['bars'] * 1.5;
 
 		$pass_color = $this->get_paint_color('PASS');
 		$fail_color = $this->get_paint_color('FAIL');
@@ -57,8 +57,8 @@ class pts_PassFailGraph extends pts_Graph
 		$identifier_width = floor(($graph_width - (($columns - 1) * $spacing)) / $columns);
 
 		$width = $identifier_width - 8;
-		$height = $line_height - 4;
-		$main_font_size = $this->text_size_bounds($this->graph_maximum_value, $this->graph_font, $font_size, 4, $width, $height);
+		$height = $identifier_height - 4;
+		$main_font_size = $this->text_size_bounds($this->i['graph_max_value'], $font_size, 4, $width, $height);
 
 		for($c = 0; $c < $columns; $c++)
 		{
@@ -68,23 +68,16 @@ class pts_PassFailGraph extends pts_Graph
 				$this_identifier = $this->graph_identifiers[$element_i];
 				$this_value = $this->graph_data[0][$element_i];
 
-				$this_horizontal_start = $this->graph_left_start + $horizontal_border + ($c * ($identifier_width + $spacing));
-				$this_horizontal_end = $this->graph_left_start + $horizontal_border + ($c * ($identifier_width + $spacing)) + $identifier_width;
-				$this_vertical_start = $this->graph_top_start + $vertical_border + ($i * ($identifier_height + $spacing));
-				$this_vertical_end = $this->graph_top_start + $vertical_border + ($i * ($identifier_height + $spacing)) + $identifier_height;
+				$this_x_start = $this->i['left_start'] + $horizontal_border + ($c * ($identifier_width + $spacing));
+				$this_x_end = $this->i['left_start'] + $horizontal_border + ($c * ($identifier_width + $spacing)) + $identifier_width;
+				$this_y_start = $this->i['top_start'] + $vertical_border + ($i * ($identifier_height + $spacing));
+				$this_y_end = $this->i['top_start'] + $vertical_border + ($i * ($identifier_height + $spacing)) + $identifier_height;
 
-				if($this_value == "PASS")
-				{
-					$paint_color = $pass_color;
-				}
-				else
-				{
-					$paint_color = $fail_color;
-				}
-
-				$this->graph_image->draw_rectangle_with_border($this_horizontal_start + 1, $this_vertical_start + 1, $this_horizontal_end - 1, $this_vertical_end - 1, $paint_color, $this->graph_color_body_light);
-
-				$this->graph_image->write_text_center($this_identifier, $this->graph_font, $font_size, $this->graph_color_body_text, $this_horizontal_start, $this_vertical_start + (($this_vertical_end - $this_vertical_start) / 2) - ($this->text_string_height($this_identifier, $this->graph_font, $font_size) / 2), $this_horizontal_end, $this_vertical_start + (($this_vertical_end - $this_vertical_start) / 2) - ($this->text_string_height($this_identifier, $this->graph_font, $font_size) / 2));
+				$paint_color = $this_value == 'PASS' ? $pass_color : $fail_color;
+				$this->svg_dom->add_element('rect', array('x' => $this_x_start, 'y' => $this_y_start, 'width' => $identifier_width, 'height' => $identifier_height, 'fill' => $paint_color, 'stroke' => self::$c['color']['body_light'], 'stroke-width' => 1));
+				$x = $this_x_start + (($this_x_end - $this_x_start) / 2);
+				$y = $this_y_start + (($this_y_end - $this_y_start) / 2);
+				$this->svg_dom->add_text_element($this_identifier, array('x' => $x, 'y' => $y, 'font-size' => $font_size, 'fill' => self::$c['color']['body_text'], 'text-anchor' => 'middle', 'dominant-baseline' => 'middle'));
 			}
 		}
 	}
