@@ -25,6 +25,10 @@ class pts_network
 	private static $disable_network_support = false;
 	private static $network_proxy = false;
 
+	public static function is_proxy_setup()
+	{
+		return self::$network_proxy == false;
+	}
 	public static function network_support_available()
 	{
 		return self::$disable_network_support == false;
@@ -141,7 +145,12 @@ class pts_network
 	public static function stream_download($download, $download_to, $stream_context_parameters = null, $callback_function = array('pts_network', 'stream_status_callback'))
 	{
 		$stream_context = pts_network::stream_context_create($stream_context_parameters);
-		stream_context_set_params($stream_context, array('notification' => $callback_function));
+
+		if(function_exists('stream_context_set_params'))
+		{
+			// HHVM 2.1 doesn't have stream_context_set_params()
+			stream_context_set_params($stream_context, array('notification' => $callback_function));
+		}
 
 		/*
 		if(strpos($download, 'https://openbenchmarking.org/') !== false)
