@@ -383,6 +383,14 @@ class pts_render
 
 		foreach($system_json as $i => $json)
 		{
+			if(isset($json['kernel-parameters']) && $json['kernel-parameters'] != null)
+			{
+				$system_attributes['Kernel'][$identifiers[$i]] = $json['kernel-parameters'];
+			}
+			if(isset($json['environment-variables']) && $json['environment-variables'] != null)
+			{
+				$system_attributes['Environment'][$identifiers[$i]] = $json['environment-variables'];
+			}
 			if(isset($json['compiler-configuration']) && $json['compiler-configuration'] != null)
 			{
 				$system_attributes['Compiler'][$identifiers[$i]] = $json['compiler-configuration'];
@@ -477,7 +485,14 @@ class pts_render
 			return false;
 		}
 
-		$compiler_options_string = '(' . strtoupper($unique_compiler_data[0]['compiler-type']) . ') ' . $unique_compiler_data[0]['compiler'] . ' options: ';
+		if(isset($unique_compiler_data[0]['compiler-type']) && isset($unique_compiler_data[0]['compiler']))
+		{
+			$compiler_options_string = '(' . strtoupper($unique_compiler_data[0]['compiler-type']) . ') ' . $unique_compiler_data[0]['compiler'] . ' options: ';
+		}
+		else
+		{
+			$compiler_options_string = null;
+		}
 
 		switch(count($unique_compiler_data))
 		{
@@ -544,40 +559,52 @@ class pts_render
 				}
 				break;
 		}
+
+		foreach($json as $identifier => &$data)
+		{
+			// TODO XXX: Ultimately merge this data into the SE +/- line...
+			if(isset($data['min-result']) && isset($data['max-result']))
+			{
+				$graph->addGraphIdentifierNote($identifier, 'MIN: ' . $data['min-result'] . ' / MAX: ' . $data['max-result']);
+			}
+		}
 	}
 	public static function evaluate_redundant_identifier_words($identifiers)
 	{
-		if(count($identifiers) < 6)
+		if(count($identifiers) < 4 || strpos(pts_arrays::first_element($identifiers), ':') !== false)
 		{
 			// Probably not worth shortening so few result identifiers
 			return false;
 		}
 
 		// Breakup the an identifier into an array by spaces to be used for comparison
-		$common_segments = explode(' ', pts_arrays::last_element($identifiers));
+		$common_segments = explode(' ', pts_arrays::first_element($identifiers));
+		$common_segments_last = explode(' ', pts_arrays::last_element($identifiers));
 
-		if(!isset($common_segments[2]))
+		if(!isset($common_segments_last[2]) || !isset($common_segments[2]))
 		{
 			// If there aren't at least three words in identifier, probably can't be shortened well
 			return false;
 		}
 
-		foreach($identifiers as &$identifier)
+		foreach(array_reverse($identifiers) as $id)
 		{
-			$this_identifier = explode(' ', $identifier);
+			$words = explode(' ', $id);
 
-			foreach($common_segments as $pos => $word)
+			foreach($words as $i => $word)
 			{
-				if(!isset($this_identifier[$pos]) || $this_identifier[$pos] != $word || !isset($word[2]) || !ctype_alnum(substr($word, -1)))
+				if(isset($common_segments[$i]) && $word != $common_segments[$i] && isset($word[2]) && !ctype_alnum(substr($word, -1)))
 				{
-					// The word isn't the same OR the string is less than three characters (e.g. i7 or HD don't chop off from product names
-					unset($common_segments[$pos]);
+					// IS COMMON WORD
+				}
+				else
+				{
+					unset($common_segments[$i]);
 				}
 			}
 
 			if(count($common_segments) == 0)
 			{
-				// There isn't any common words to each identifier in result set
 				return false;
 			}
 		}
@@ -824,7 +851,7 @@ class pts_render
 		{
 			$mto->test_profile->set_result_scale($mto->test_profile->get_result_scale() . ' | ' . implode(',', array_keys($days)));
 
-			if($is_tracking && $buffer_count < 16 && $result_file && pts_result_file_analyzer::analyze_result_file_intent($result_file) != false)
+			if($is_tracking && $buffer_count < 16 && $result_file && pts_result_file_analyzer::analyze_result_file_intent($result_file) == false)
 			{
 				// It can't be a tracker if the result file is comparing hardware/software, etc
 				$is_tracking = false;
@@ -1015,9 +1042,11 @@ class pts_render
 				$selected_renderer = 'PNG';
 			}
 		}
-		else if(($p = strpos($user_agent, 'AppleWebKit/')) !== false)
+		else if(($p = strpos($user_agent, 'AppleWebKit/')) !== false && strpos($user_agent, 'Chrome/') === false)
 		{
+			// All modern versions of Chrome should work with SVG
 			// Safari, Google Chrome, Google Chromium, etc
+			// Any version of Chrome should be okay
 			$webkit_ver = substr($user_agent, ($p + 12));
 			$webkit_ver = substr($webkit_ver, 0, strpos($webkit_ver, ' '));
 
