@@ -59,7 +59,7 @@ class pts_result_file_merge_manager
 		if($this->skip_subsystems != null)
 		{
 			// Check whether to omit rendering this test if only certain subsystem test types should be merged
-			$test_subsystem = pts_tests::test_hardware_type($merge_test_object->test_profile->get_identifier());
+			$test_subsystem = $merge_test_object->test_profile->get_test_hardware_type();
 
 			if($test_subsystem != null && !in_array($test_subsystem, $this->skip_subsystems))
 			{
@@ -89,7 +89,7 @@ class pts_result_file_merge_manager
 
 					if($this->result_already_contained($this->test_results[$mto_hash], $buffer_item) == false)
 					{
-						$this->test_results[$mto_hash]->test_result_buffer->add_test_result($this_identifier, $buffer_item->get_result_value(), $buffer_item->get_result_raw());
+						$this->test_results[$mto_hash]->test_result_buffer->add_test_result($this_identifier, $buffer_item->get_result_value(), $buffer_item->get_result_raw(), $buffer_item->get_result_json());
 					}
 				}
 			}
@@ -125,7 +125,7 @@ class pts_result_file_merge_manager
 							$this_identifier = $renamed;
 						}
 
-						$merge_test_object->test_result_buffer->add_test_result($this_identifier, $buffer_item->get_result_value(), $buffer_item->get_result_raw());
+						$merge_test_object->test_result_buffer->add_test_result($this_identifier, $buffer_item->get_result_value(), $buffer_item->get_result_raw(), $buffer_item->get_result_json());
 					}
 				}
 			}
