@@ -24,13 +24,21 @@ class pts_test_result
 {
 	// Note in most pts-core code the initialized var is called $result_object
 	// Note in pts-core code the initialized var is also called $test_run_request
-	private $result;
+	private $result = 0;
+	private $result_min = 0;
+	private $result_max = 0;
 	private $used_arguments;
 	private $used_arguments_description;
 
 	public $test_profile;
 	public $test_result_buffer;
 
+	public $active_result = null;
+	public $active_min_result = null;
+	public $active_max_result = null;
+
+	public $secondary_linked_results = null;
+
 	public function __construct(&$test_profile)
 	{
 		$this->test_profile = $test_profile;
@@ -64,10 +72,26 @@ class pts_test_result
 	{
 		$this->result = $result;
 	}
+	public function set_min_result($result)
+	{
+		$this->result_min = $result;
+	}
+	public function set_max_result($result)
+	{
+		$this->result_max = $result;
+	}
 	public function get_result()
 	{
 		return $this->result;
 	}
+	public function get_min_result()
+	{
+		return $this->result_min;
+	}
+	public function get_max_result()
+	{
+		return $this->result_max;
+	}
 	public function get_comparison_hash($show_version_and_attributes = true)
 	{
 		if($show_version_and_attributes)
