@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2012, Phoronix Media
-	Copyright (C) 2010 - 2012, Michael Larabel
+	Copyright (C) 2010 - 2013, Phoronix Media
+	Copyright (C) 2010 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -205,24 +205,88 @@ class pts_test_result_parser
 		switch($test_run_request->test_profile->get_display_format())
 		{
 			case 'IMAGE_COMPARISON':
-				$test_result = self::parse_iqc_result($test_run_request->test_profile, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
+				$test_run_request->active_result = self::parse_iqc_result($test_run_request->test_profile, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
 				break;
 			case 'PASS_FAIL':
 			case 'MULTI_PASS_FAIL':
-				$test_result = self::parse_generic_result($test_identifier, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
+				$test_run_request->active_result = self::parse_generic_result($test_identifier, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
 				break;
 			case 'BAR_GRAPH':
 			default:
-				$test_result = self::parse_numeric_result($test_identifier, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
+				$test_run_request->active_result = self::parse_numeric_result($test_identifier, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
 
-				if($test_run_request->test_profile->get_display_format() == 'BAR_GRAPH' && !is_numeric($test_result))
+				if($test_run_request->test_profile->get_display_format() == 'BAR_GRAPH' && !is_numeric($test_run_request->active_result))
 				{
-					$test_result = false;
+					$test_run_request->active_result = false;
+				}
+				else
+				{
+					$test_run_request->active_min_result = self::parse_numeric_result($test_identifier, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments, 'MIN');
+					$test_run_request->active_max_result = self::parse_numeric_result($test_identifier, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments, 'MAX');
 				}
 				break;
 		}
+	}
+	public static function generate_extra_data(&$test_result, &$test_log_file = null)
+	{
+		$parse_xml_file = $test_result->test_profile->get_file_parser_spec();
 
-		return $test_result;
+		if($parse_xml_file == false)
+		{
+			return;
+		}
+
+		$results_parser_xml = new pts_parse_results_nye_XmlReader($parse_xml_file);
+		$extra_data_identifiers = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ExtraData/Identifier');
+		$extra_results = array();
+
+		foreach(array_keys($extra_data_identifiers) as $i)
+		{
+			$id = $extra_data_identifiers[$i];
+
+			switch($id)
+			{
+				case 'com-speeds-frame-latency-totals':
+					$log_file = pts_file_io::file_get_contents($test_log_file);
+					$frame_all_times = array();
+					while(($log_file = strstr($log_file, 'frame:')))
+					{
+						if(($a = strpos($log_file, ' all: ')) !== false && $a < strpos($log_file, "\n"))
+						{
+							$all = ltrim(substr($log_file, $a + 6));
+							$all = substr($all, 0, strpos($all, ' '));
+
+							if(is_numeric($all) && $all > 0)
+							{
+								array_push($frame_all_times, $all);
+							}
+						}
+						$log_file = strstr($log_file, 'bk:');
+					}
+
+					if(isset($frame_all_times[60]))
+					{
+						// Take off the first frame as it's likely to have taken much longer when game just starting off...
+						array_shift($frame_all_times);
+						$tp = clone $test_result->test_profile;
+						$tp->set_result_scale('Milliseconds');
+						$tp->set_result_proportion('LIB');
+						$tp->set_display_format('LINE_GRAPH');
+						$tp->set_identifier(null);
+						$extra_result = new pts_test_result($tp);
+						$extra_result->set_used_arguments_description('Total Frame Time');
+						$extra_result->set_result(implode(',', $frame_all_times));
+						array_push($extra_results, $extra_result);
+						//$extra_result->set_used_arguments(phodevi::sensor_name($sensor) . ' ' . $test_result->get_arguments());
+					}
+					break;
+			}
+		}
+
+		if(!empty($extra_results))
+		{
+			$test_result->secondary_linked_results = $extra_results;
+		}
 	}
 	public static function calculate_end_result(&$test_result)
 	{
@@ -328,6 +392,25 @@ class pts_test_result_parser
 						{
 							$END_RESULT = round($END_RESULT);
 						}
+
+						if(count($min = $test_result->test_result_buffer->get_min_values()) > 0)
+						{
+							$min = round(min($min), 2);
+
+							if($min < $END_RESULT && is_numeric($min) && $min != 0)
+							{
+								$test_result->set_min_result($min);
+							}
+						}
+						if(count($max = $test_result->test_result_buffer->get_max_values()) > 0)
+						{
+							$max = round(max($max), 2);
+
+							if($max > $END_RESULT && is_numeric($max) && $max != 0)
+							{
+								$test_result->set_max_result($max);
+							}
+						}
 						break;
 				}
 				break;
@@ -390,15 +473,15 @@ class pts_test_result_parser
 
 		return $test_result;
 	}
-	protected static function parse_numeric_result($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments)
+	protected static function parse_numeric_result($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments, $prefix = null)
 	{
-		return self::parse_result_process($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments, true);
+		return self::parse_result_process($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments, true, $prefix);
 	}
-	protected static function parse_generic_result($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments)
+	protected static function parse_generic_result($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments, $prefix = null)
 	{
-		return self::parse_result_process($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments, false);
+		return self::parse_result_process($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments, false, $prefix);
 	}
-	protected static function parse_result_process($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments, $is_numeric_check = true)
+	protected static function parse_result_process($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments, $is_numeric_check = true, $prefix = null)
 	{
 		$results_parser_xml = new pts_parse_results_nye_XmlReader($parse_xml_file);
 		$result_match_test_arguments = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/MatchToTestArguments');
@@ -415,6 +498,11 @@ class pts_test_result_parser
 		$multi_match = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/MultiMatch');
 		$test_result = false;
 
+		if($prefix != null && substr($prefix, -1) != '_')
+		{
+			$prefix .= '_';
+		}
+
 		for($i = 0; $i < count($result_template); $i++)
 		{
 			if(!empty($result_match_test_arguments[$i]) && strpos($pts_test_arguments, $result_match_test_arguments[$i]) === false)
@@ -425,28 +513,42 @@ class pts_test_result_parser
 
 			if($result_key[$i] == null)
 			{
-				$result_key[$i] = '#_RESULT_#';
+				$result_key[$i] = '#_' . $prefix . 'RESULT_#';
 			}
 			else
 			{
 				switch($result_key[$i])
 				{
 					case 'PTS_TEST_ARGUMENTS':
-						$result_key[$i] = '#_' . str_replace(' ', '', $pts_test_arguments) . '_#';
+						$result_key[$i] = '#_' . $prefix . str_replace(' ', '', $pts_test_arguments) . '_#';
 						break;
 					case 'PTS_USER_SET_ARGUMENTS':
-						$result_key[$i] = '#_' . str_replace(' ', '', $extra_arguments) . '_#';
+						$result_key[$i] = '#_' . $prefix . str_replace(' ', '', $extra_arguments) . '_#';
 						break;
 				}
 			}
 
 			// The actual parsing here
 			$start_result_pos = strrpos($result_template[$i], $result_key[$i]);
+
+			if($prefix != null && $start_result_pos === false)
+			{
+				// XXX: technically the $prefix check shouldn't be needed, verify whether safe to have this check be unconditional on start_result_pos failing...
+				return false;
+			}
+
+			$space_out_chars = array('(', ')', "\t");
+
+			if((isset($result_template[$i][($start_result_pos - 1)]) && $result_template[$i][($start_result_pos - 1)] == '/') || (isset($result_template[$i][($start_result_pos + strlen($result_key[$i]))]) && $result_template[$i][($start_result_pos + strlen($result_key[$i]))] == '/'))
+			{
+				array_push($space_out_chars, '/');
+			}
+
 			$end_result_pos = $start_result_pos + strlen($result_key[$i]);
 			$end_result_line_pos = strpos($result_template[$i], "\n", $end_result_pos);
 			$result_template_line = substr($result_template[$i], 0, ($end_result_line_pos === false ? strlen($result_template[$i]) : $end_result_line_pos));
 			$result_template_line = substr($result_template_line, strrpos($result_template_line, "\n"));
-			$result_template_r = explode(' ', pts_strings::trim_spaces(str_replace(array('(', ')', "\t"), ' ', str_replace('=', ' = ', $result_template_line))));
+			$result_template_r = explode(' ', pts_strings::trim_spaces(str_replace($space_out_chars, ' ', str_replace('=', ' = ', $result_template_line))));
 			$result_template_r_pos = array_search($result_key[$i], $result_template_r);
 
 			if($result_template_r_pos === false)
@@ -465,15 +567,15 @@ class pts_test_result_parser
 			$search_key = null;
 			$line_before_key = null;
 
-			if($result_line_hint[$i] != null && strpos($result_template_line, $result_line_hint[$i]) !== false)
+			if(isset($result_line_hint[$i]) && $result_line_hint[$i] != null && strpos($result_template_line, $result_line_hint[$i]) !== false)
 			{
 				$search_key = $result_line_hint[$i];
 			}
-			else if($result_line_before_hint[$i] != null && strpos($result_template[$i], $result_line_hint[$i]) !== false)
+			else if(isset($result_line_before_hint[$i]) && $result_line_before_hint[$i] != null && strpos($result_template[$i], $result_line_hint[$i]) !== false)
 			{
 				$search_key = null; // doesn't really matter what this value is
 			}
-			else if($result_line_after_hint[$i] != null && strpos($result_template[$i], $result_line_hint[$i]) !== false)
+			else if(isset($result_line_after_hint[$i]) && $result_line_after_hint[$i] != null && strpos($result_template[$i], $result_line_hint[$i]) !== false)
 			{
 				$search_key = null; // doesn't really matter what this value is
 			}
@@ -489,7 +591,7 @@ class pts_test_result_parser
 					}
 				}
 
-				if($search_key == null)
+				if($search_key == null && isset($result_key[$i]))
 				{
 					// Just try searching for the first part of the string
 					/*
@@ -516,7 +618,7 @@ class pts_test_result_parser
 
 			$test_results = array();
 
-			if($search_key != null || $result_line_before_hint[$i] != null || $result_line_after_hint[$i] != null || $result_template_r[0] == $result_key[$i])
+			if($search_key != null || (isset($result_line_before_hint[$i]) && $result_line_before_hint[$i] != null) || (isset($result_line_after_hint[$i]) && $result_line_after_hint[$i]) != null || (isset($result_key[$i]) && $result_template_r[0] == $result_key[$i]))
 			{
 				$is_multi_match = !empty($multi_match[$i]) && $multi_match[$i] != 'NONE';
 
@@ -553,10 +655,9 @@ class pts_test_result_parser
 						pts_client::test_profile_debug_message('No Result Parsing Hint, Including Entire Result Output');
 						$result_line = trim($result_output);
 					}
-
 					pts_client::test_profile_debug_message('Result Line: ' . $result_line);
 
-					$result_r = explode(' ', pts_strings::trim_spaces(str_replace(array('(', ')', "\t"), ' ', str_replace('=', ' = ', $result_line))));
+					$result_r = explode(' ', pts_strings::trim_spaces(str_replace($space_out_chars, ' ', str_replace('=', ' = ', $result_line))));
 					$result_r_pos = array_search($result_key[$i], $result_r);
 
 					if(!empty($result_before_string[$i]))
