@@ -61,6 +61,18 @@ function pts_define_directories()
 		pts_define('PTS_TEST_SUITE_PATH', PTS_USER_PATH . 'test-suites/');
 		pts_define('PTS_RESULTS_VIEWER_PATH', PTS_CORE_PATH . 'results-viewer/');
 	}
+	else if(defined('PTS_STORAGE_PATH'))
+	{
+		pts_define('PTS_OPENBENCHMARKING_SCRATCH_PATH', PTS_STORAGE_PATH . 'openbenchmarking.org/');
+		pts_define('PTS_TEST_PROFILE_PATH', PTS_STORAGE_PATH . 'test-profiles/');
+		pts_define('PTS_TEST_SUITE_PATH', PTS_STORAGE_PATH . 'test-suites/');
+	}
+	else if(defined('PATH_TO_PHOROMATIC_STORAGE'))
+	{
+		pts_define('PTS_OPENBENCHMARKING_SCRATCH_PATH', PATH_TO_PHOROMATIC_STORAGE . 'openbenchmarking.org/');
+		pts_define('PTS_TEST_PROFILE_PATH', PATH_TO_PHOROMATIC_STORAGE . 'test-profiles/');
+		pts_define('PTS_TEST_SUITE_PATH', PATH_TO_PHOROMATIC_STORAGE . 'test-suites/');
+	}
 
 	// Misc Locations
 	pts_define('PTS_MODULE_PATH', PTS_CORE_PATH . 'modules/');
@@ -90,32 +102,43 @@ function pts_needed_extensions()
 function pts_version_codenames()
 {
 	return array(
+		// Sør-Trøndelag - Norway
 		'1.0' => 'Trondheim',
 		'1.2' => 'Malvik',
 		'1.4' => 'Orkdal',
 		'1.6' => 'Tydal',
 		'1.8' => 'Selbu',
+		// Troms - Norway
 		'2.0' => 'Sandtorg',
 		'2.2' => 'Bardu',
 		'2.4' => 'Lenvik',
 		'2.6' => 'Lyngen',
 		'2.8' => 'Torsken',
+		// Aust-Agder - Norway
 		'2.9' => 'Iveland', // early PTS3 development work
 		'3.0' => 'Iveland',
 		'3.2' => 'Grimstad',
 		'3.4' => 'Lillesand',
 		'3.6' => 'Arendal',
 		'3.8' => 'Bygland',
+		// Rogaland - Norway
 		'4.0' => 'Suldal',
 		'4.2' => 'Randaberg',
 		'4.4' => 'Forsand',
-		'4.6' => 'Utsira'
+		'4.6' => 'Utsira',
+		'4.8' => 'Sokndal',
+		// Tulskaya oblast / Tula Oblast region - Russia
+		'5.0' => 'Plavsk',
+		'5.2' => 'Khanino',
+		'5.4' => 'Lipki',
+		'5.6' => 'Dedilovo',
+		'5.8' => 'Belev',
 		);
 }
 
-pts_define('PTS_VERSION', '4.6.0');
-pts_define('PTS_CORE_VERSION', 4600);
-pts_define('PTS_CODENAME', 'UTSIRA');
+pts_define('PTS_VERSION', '4.8.3');
+pts_define('PTS_CORE_VERSION', 4830);
+pts_define('PTS_CODENAME', 'SOKNDAL');
 pts_define('PTS_IS_CLIENT', (defined('PTS_MODE') && PTS_MODE == 'CLIENT'));
 pts_define('PTS_IS_DEV_BUILD', (substr(PTS_VERSION, -2, 1) == 'm'));
 
